pub fn run_fixture(fixture_json: &str) -> Result<FullChainEvidence>Expand description
Runs the fixture scenario for the local smoke workflow.
pub fn run_fixture(fixture_json: &str) -> Result<FullChainEvidence>Runs the fixture scenario for the local smoke workflow.