CheckoutCompletion

Struct CheckoutCompletion 

pub struct CheckoutCompletion { /* private fields */ }
Checkout completion used by the local smoke-test workflow; it exercises the local shell with deterministic fixtures and no external side effects.

Implementations

Source

impl CheckoutCompletion

pub fn status(&self) -> Status

Returns the status evidence available to local smoke-test review while leaving provider, customer, payment, and schedule systems unchanged.

pub const fn completion_status(&self) -> CompletionStatus

Returns the completion status evidence available to local smoke-test review while leaving provider, customer, payment, and schedule systems unchanged.

pub fn required_review_gates(&self) -> &[ReviewGate]

Returns the required review gates evidence available to local smoke-test review while leaving provider, customer, payment, and schedule systems unchanged.

pub fn blocked_actions(&self) -> &[BlockedAction]

Returns the blocked actions evidence available to local smoke-test review while leaving provider, customer, payment, and schedule systems unchanged.