SmokeBoundaries

Struct SmokeBoundaries 

pub struct SmokeBoundaries { /* private fields */ }
Smoke boundaries carried by the local smoke-test workflow; it exercises the local shell with deterministic fixtures and no external side effects.

Implementations

Source

impl SmokeBoundaries

pub const fn draft_only_ai(&self) -> bool

Returns the draft only ai source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn blocks_live_customer_sends(&self) -> bool

Returns the blocks live customer sends source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn blocks_provider_or_pms_mutations(&self) -> bool

Returns the blocks provider or pms mutations source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn blocks_payment_refund_or_discount_actions(&self) -> bool

Returns the blocks payment refund or discount actions source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.