pub struct CheckoutCompletion { /* private fields */ }Expand description
Checkout completion carried by the local smoke-test workflow; it exercises the local shell with deterministic fixtures and no external side effects.
Implementations
Sourceimpl CheckoutCompletion
impl CheckoutCompletion
Sourcepub fn status(&self) -> Status
pub fn status(&self) -> Status
Returns the status source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn completion_status(&self) -> CompletionStatus
pub const fn completion_status(&self) -> CompletionStatus
Returns the completion status source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.