pub struct FullChainEvidence { /* private fields */ }Expand description
Full chain evidence carried by the local smoke-test workflow; it exercises the local shell with deterministic fixtures and no external side effects.
Implementations
Sourceimpl FullChainEvidence
impl FullChainEvidence
Sourcepub const fn source_event_key(&self) -> &SourceEventKey
pub const fn source_event_key(&self) -> &SourceEventKey
Returns the source event key source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn stage_names(&self) -> Vec<&'static str>
pub fn stage_names(&self) -> Vec<&'static str>
Returns the stage names source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn boundaries(&self) -> &SmokeBoundaries
pub const fn boundaries(&self) -> &SmokeBoundaries
Returns the boundaries source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn booking_packet(&self) -> &StaffEvaluationPacket
pub const fn booking_packet(&self) -> &StaffEvaluationPacket
Returns the booking packet source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn confirmation_draft(&self) -> &SmokeConfirmationDraft
pub const fn confirmation_draft(&self) -> &SmokeConfirmationDraft
Returns the confirmation draft source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn today_view(&self) -> &TodayView
pub const fn today_view(&self) -> &TodayView
Returns the today view source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn daily_update_preview(&self) -> &MvpPreview
pub const fn daily_update_preview(&self) -> &MvpPreview
Returns the daily update preview source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn checkout_completion(&self) -> &CheckoutCompletion
pub const fn checkout_completion(&self) -> &CheckoutCompletion
Returns the checkout completion source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn retention_follow_up(&self) -> &RetentionFollowUp
pub const fn retention_follow_up(&self) -> &RetentionFollowUp
Returns the retention follow up source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn review_gated_evidence_refs(&self) -> &[ReviewEvidenceRef]
pub fn review_gated_evidence_refs(&self) -> &[ReviewEvidenceRef]
Returns the review gated evidence refs source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.