pub struct RetentionFollowUp { /* private fields */ }Expand description
Retention follow up carried by the local smoke-test workflow; it exercises the local shell with deterministic fixtures and no external side effects.
Implementations
Sourceimpl RetentionFollowUp
impl RetentionFollowUp
Sourcepub const fn next_action(&self) -> RetentionNextAction
pub const fn next_action(&self) -> RetentionNextAction
Returns the next action source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn review_gate(&self) -> ReviewGate
pub fn review_gate(&self) -> ReviewGate
Returns the review gate source evidence carried by this local smoke-test workflow artifact without changing provider, customer, payment, or schedule state.